==> libminigui-3.2.3.tar.gz: libminigui-3.2.3/src/sysres/bmp/skin_tbslider_h.gif.c <==
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_tbslider_h.gif"

unsigned char _mgir_gif_skin_tbslider_h_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x05,0x00,	0x05,0x00,0x84,0x11,0x00,0x3D,0x3D,0x3D,
	0x56,0x56,0x56,0x5B,0x5B,0x5B,0x63,0x63,	0x63,0x68,0x68,0x68,0x93,0x93,0x93,0xA1,
	0xA1,0xA1,0xA6,0xA6,0xA6,0xE0,0xE0,0xE0,	0xE1,0xE1,0xE1,0xE5,0xE5,0xE5,0xE9,0xE9,
	0xE9,0xEE,0xEE,0xEE,0xF3,0xF3,0xF3,0xF6,	0xF6,0xF6,0xF8,0xF8,0xF8,0xF9,0xF9,0xF9,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0x21,0xFE,0x15,
	0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,	0x77,0x69,0x74,0x68,0x20,0x54,0x68,0x65,
	0x20,0x47,0x49,0x4D,0x50,0x00,0x2C,0x00,	0x00,0x00,0x00,0x05,0x00,0x05,0x00,0x00,
	0x05,0x14,0xE0,0x21,0x00,0x24,0x51,0x30,	0xD0,0x12,0x24,0x0F,0xF4,0x0C,0x0E,0x04,
	0x35,0x86,0xF2,0x3C,0x48,0x08,0x00,0x3B
};
#endif //_MGINCORE_RES

==> libminigui-4.0.2.tar.gz: libminigui-4.0.2/src/sysres/bmp/skin_tbslider_h.gif.c <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_tbslider_h.gif"

const unsigned char _mgir_gif_skin_tbslider_h_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x05,0x00,	0x05,0x00,0x84,0x11,0x00,0x3D,0x3D,0x3D,
	0x56,0x56,0x56,0x5B,0x5B,0x5B,0x63,0x63,	0x63,0x68,0x68,0x68,0x93,0x93,0x93,0xA1,
	0xA1,0xA1,0xA6,0xA6,0xA6,0xE0,0xE0,0xE0,	0xE1,0xE1,0xE1,0xE5,0xE5,0xE5,0xE9,0xE9,
	0xE9,0xEE,0xEE,0xEE,0xF3,0xF3,0xF3,0xF6,	0xF6,0xF6,0xF8,0xF8,0xF8,0xF9,0xF9,0xF9,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0x21,0xFE,0x15,
	0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,	0x77,0x69,0x74,0x68,0x20,0x54,0x68,0x65,
	0x20,0x47,0x49,0x4D,0x50,0x00,0x2C,0x00,	0x00,0x00,0x00,0x05,0x00,0x05,0x00,0x00,
	0x05,0x14,0xE0,0x21,0x00,0x24,0x51,0x30,	0xD0,0x12,0x24,0x0F,0xF4,0x0C,0x0E,0x04,
	0x35,0x86,0xF2,0x3C,0x48,0x08,0x00,0x3B
};
#endif //_MGINCORE_RES
